@@ -1,14 +1,14 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at kdemail dot net>
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
  *          Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Date   : 2006-09-15
  * Description : Exiv2 library interface for KDE
  *
  * Copyright 2006-2007 by Gilles Caulier and Marcel Wiesweg
  *
- * NOTE: Do not use kdDebug() in this library because it will
- *        be used in multithreaded implementations. Use qDebug()
- *        instead. See B.K.O #133026 for details.
+ * NOTE: Do not use kdDebug() in this implementation because 
+ *       it will be multithreaded. Use qDebug() instead. 
+ *       See B.K.O #133026 for details.
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -186,7 +186,8 @@ QByteArray KExiv2::getExif() const
             Exiv2::ExifData& exif = d->exifMetadata;
             Exiv2::DataBuf c2 = exif.copy();
             QByteArray data(c2.size_);
-            memcpy(data.data(), c2.pData_, c2.size_);
+            if (data.size())
+                memcpy(data.data(), c2.pData_, c2.size_);
             return data;
         }
     }
@@ -226,7 +227,8 @@ QByteArray KExiv2::getIptc(bool addIrbHeader) const
                 c2 = iptc.copy();
 
             QByteArray data(c2.size_);
-            memcpy(data.data(), c2.pData_, c2.size_);
+            if (data.size())
+                memcpy(data.data(), c2.pData_, c2.size_);
             return data;
         }
     }
@@ -1222,7 +1224,8 @@ QByteArray KExiv2::getExifTagData(const char* exifTagName) const
         if (it != exifData.end())
         {
             QByteArray data((*it).size());
-            (*it).copy((Exiv2::byte*)data.data(), exifData.byteOrder());
+            if (data.size())
+                (*it).copy((Exiv2::byte*)data.data(), exifData.byteOrder());
             return data;
         }
     }
@@ -1245,7 +1248,8 @@ QByteArray KExiv2::getIptcTagData(const char *iptcTagName) const
         if (it != iptcData.end())
         {
             QByteArray data((*it).size());
-            (*it).copy((Exiv2::byte*)data.data(), Exiv2::bigEndian);
+            if (data.size())
+                (*it).copy((Exiv2::byte*)data.data(), Exiv2::bigEndian);
             return data;
         }
     }
